@@ -28,23 +28,20 @@ def update_id_lst(record_lst, job_id_lst):
 
 
 def extract_archive(archive_directory):
-    fname = archive_directory+".tar.gz"
+    fname = archive_directory + ".tar.gz"
     tar = tarfile.open(fname, "r:gz")
     tar.extractall()
     tar.close()
 
 
-def import_jobs(
-    project_instance, archive_directory,
-    df, compressed=True
-):
+def import_jobs(project_instance, archive_directory, df, compressed=True):
     # Copy HDF5 files
     # if the archive_directory is a path(string)/name of the compressed file
     if static_isinstance(
         obj=archive_directory.__class__,
         obj_type=[
             "pyiron_base.project.generic.Project",
-        ]
+        ],
     ):
         archive_directory = archive_directory.path
     elif isinstance(archive_directory, str):
@@ -74,25 +71,25 @@ def import_jobs(
     # # Update Database
     pr_import = project_instance.open(os.curdir)
 
-    df["project"] = [os.path.join(
-        pr_import.project_path, os.path.relpath(p, archive_name)) + "/"
+    df["project"] = [
+        os.path.join(pr_import.project_path, os.path.relpath(p, archive_name)) + "/"
         for p in df["project"].values
     ]
-    df['projectpath'] = len(df) * [pr_import.root_path]
+    df["projectpath"] = len(df) * [pr_import.root_path]
     # Add jobs to database
     job_id_lst = []
     for entry in df.dropna(axis=1).to_dict(orient="records"):
-        if 'id' in entry:
-            del entry['id']
-        if 'parentid' in entry:
-            del entry['parentid']
-        if 'masterid' in entry:
-            del entry['masterid']
-        if 'timestart' in entry:
+        if "id" in entry:
+            del entry["id"]
+        if "parentid" in entry:
+            del entry["parentid"]
+        if "masterid" in entry:
+            del entry["masterid"]
+        if "timestart" in entry:
             entry["timestart"] = pandas.to_datetime(entry["timestart"])
-        if 'timestop' in entry:
+        if "timestop" in entry:
             entry["timestop"] = pandas.to_datetime(entry["timestop"])
-        if 'username' not in entry:
+        if "username" not in entry:
             entry["username"] = state.settings.login_user
         job_id = pr_import.db.add_item_dict(par_dict=entry)
         job_id_lst.append(job_id)
@@ -105,8 +102,5 @@ def import_jobs(
     ):
         if masterid is not None or parentid is not None:
             pr_import.db.item_update(
-                item_id=job_id,
-                par_dict={
-                    "parentid": parentid, "masterid": masterid
-                }
+                item_id=job_id, par_dict={"parentid": parentid, "masterid": masterid}
             )
